@@ -1,6 +1,7 @@
 from wfuzz.plugin_api.base import BasePlugin
 from wfuzz.externals.moduleman.plugin import moduleman_plugin
 
+
 @moduleman_plugin
 class title(BasePlugin):
     name = "title"
@@ -15,16 +16,15 @@ class title(BasePlugin):
     )
 
     def __init__(self):
-	BasePlugin.__init__(self)
+        BasePlugin.__init__(self)
 
     def validate(self, fuzzresult):
-	return True
+        return True
 
     def process(self, fuzzresult):
         soup = fuzzresult.history.get_soup()
         title = soup.title.string if soup.title else ""
 
-        if title != "" and not "title" in self.kbase or title not in self.kbase["title"]:
+        if title != "" and "title" not in self.kbase or title not in self.kbase["title"]:
             self.kbase["title"] = title
             self.add_result("Page title: %s" % title)
-
